==> 1.1.1.tar.gz: android/src/main/kotlin/com/fireworksdk/bridge/flutter/platformview/FWVideoFeedPlatformView.kt <==
package com.fireworksdk.bridge.flutter.platformview

import android.app.Activity
import android.view.View
import com.fireworksdk.bridge.components.videofeed.FWVideoFeed
import com.fireworksdk.bridge.flutter.handler.FWVideoFeedHandler
import com.fireworksdk.bridge.flutter.models.FWChannelName
import com.fireworksdk.bridge.models.FWVideoFeedPropsModel
import com.fireworksdk.bridge.flutter.utils.FWEventUtils
import com.fireworksdk.bridge.models.*
import com.fireworksdk.bridge.utils.FWJsonUtils
import com.fireworksdk.bridge.utils.FWLogUtils
import com.loopnow.fireworklibrary.models.OnPlaylistGroupItemClickedListener
import com.loopnow.fireworklibrary.models.VideoContentStatus
import com.loopnow.fireworklibrary.views.OnItemClickedListener
import com.loopnow.fireworklibrary.views.OnVideoContentStatusListener
import io.flutter.plugin.common.BinaryMessenger
import io.flutter.plugin.common.MethodChannel
import io.flutter.plugin.platform.PlatformView

class FWVideoFeedPlatformView(
    activity: Activity,
    id: Int,
    creationParams: Map<String?, Any?>?,
    binaryMessenger : BinaryMessenger,
    fwSdkModuleChannel: MethodChannel?,
): PlatformView {

    val videoFeed: FWVideoFeed = FWVideoFeed(activity)
    private val methodChannel = MethodChannel(
        binaryMessenger,
        FWChannelName.FireworkVideoFeed.rawValue.replace("(viewId)", "$id")
    )

    private val fwSdkModuleChannel by weakProperty<MethodChannel?>(fwSdkModuleChannel)

    init {
        methodChannel.setMethodCallHandler(FWVideoFeedHandler(this))

        val videoFeedProps: FWVideoFeedPropsModel? = FWJsonUtils.fromMap(creationParams, FWVideoFeedPropsModel::class.java)
        setProps(videoFeedProps)
        addVideoFeedListener()
        addPlaylistGroupFeedListener()
    }

    private fun setProps(props: FWVideoFeedPropsModel?) {
        videoFeed.setProps(props)
    }

    private fun addVideoFeedListener() {
        videoFeed.videoFeedView?.addOnItemClickedListener(object: OnItemClickedListener {
            override fun onItemClicked(index: Int, title: String, id: String, videoDuration: Long) {
                val fwVideoFeedItemDetailsModel = FWVideoFeedItemDetailsModel(
                    index,
                    id,
                    videoDuration.toInt(),
                    videoFeed.videoFeedPropsModel.source,
                    title,
                    videoFeed.videoFeedPropsModel.playlistGroup,
                    videoFeed.videoFeedPropsModel.playlist,
                    videoFeed.videoFeedPropsModel.channel,
                    videoFeed.videoFeedPropsModel.dynamicContentParameters
                )
                FWEventUtils.sendVideoFeedClickEvent(fwSdkModuleChannel, fwVideoFeedItemDetailsModel)
            }

            override fun onItemClicked(index: Int) {
                super.onItemClicked(index)
            }

            override fun onItemClicked(index: Int, feedId: Int): Boolean {
                return super.onItemClicked(index, feedId)
            }
        })
        videoFeed.videoFeedView?.addOnVideoContentStatusListener(object: OnVideoContentStatusListener {
            override fun currentStatus(status: VideoContentStatus, extra: String) {
                when (status) {
                    VideoContentStatus.LoadingContent -> {
                        FWLogUtils.d { "VideoContentStatus.LoadingContent" }
                    }
                    VideoContentStatus.LoadingContentFailed -> {
                        FWLogUtils.e { "VideoContentStatus.LoadingContentFailed" }
                        FWEventUtils.sendVideoFeedLoadFailedEvent(methodChannel, VideoContentStatus.LoadingContentFailed.rawValue, extra)
                    }
                    VideoContentStatus.ContentLoaded -> {
                        FWLogUtils.d { "VideoContentStatus.ContentLoaded" }
                        FWEventUtils.sendVideoFeedLoadSuccessEvent(methodChannel)
                    }
                }
            }
        })
    }

    private fun addPlaylistGroupFeedListener() {
        videoFeed.playlistGroupFeedView?.itemClickHandler = object :
            OnPlaylistGroupItemClickedListener {
            override fun onItemClicked(index: Int, id: String?): Boolean {
                val fwVideoFeedItemDetailsModel = FWVideoFeedItemDetailsModel(
                    index,
                    id,
                    0,
                    videoFeed.videoFeedPropsModel.source,
                    "",
                    videoFeed.videoFeedPropsModel.playlistGroup,
                    videoFeed.videoFeedPropsModel.playlist,
                    videoFeed.videoFeedPropsModel.channel,
                    videoFeed.videoFeedPropsModel.dynamicContentParameters
                )
                FWEventUtils.sendVideoFeedClickEvent(fwSdkModuleChannel, fwVideoFeedItemDetailsModel)
                return false
            }
        }

        videoFeed.playlistGroupFeedView?.addOnVideoContentStatusListener(object: OnVideoContentStatusListener {
            override fun currentStatus(status: VideoContentStatus, extra: String) {
                when (status) {
                    VideoContentStatus.LoadingContent -> {
                        FWLogUtils.d { "VideoContentStatus.LoadingContent" }
                    }
                    VideoContentStatus.LoadingContentFailed -> {
                        FWLogUtils.e { "VideoContentStatus.LoadingContentFailed" }
                        FWEventUtils.sendVideoFeedLoadFailedEvent(methodChannel, VideoContentStatus.LoadingContentFailed.rawValue, extra)
                    }
                    VideoContentStatus.ContentLoaded -> {
                        FWLogUtils.d { "VideoContentStatus.ContentLoaded" }
                        FWEventUtils.sendVideoFeedLoadSuccessEvent(methodChannel)
                    }
                }
            }
        })
    }

    override fun getView(): View {
        return videoFeed
    }

    override fun dispose() {
    }
}

==> 1.5.1.tar.gz: android/src/main/kotlin/com/fireworksdk/bridge/flutter/platformview/FWVideoFeedPlatformView.kt <==
package com.fireworksdk.bridge.flutter.platformview

import android.app.Activity
import android.view.View
import com.fireworksdk.bridge.components.videofeed.FWVideoFeed
import com.fireworksdk.bridge.flutter.handler.FWVideoFeedHandler
import com.fireworksdk.bridge.flutter.models.FWChannelName
import com.fireworksdk.bridge.models.FWVideoFeedPropsModel
import com.fireworksdk.bridge.flutter.utils.FWEventUtils
import com.fireworksdk.bridge.models.*
import com.fireworksdk.bridge.utils.FWGsonUtil
import com.fireworksdk.bridge.utils.FWLogUtils
import com.loopnow.fireworklibrary.models.OnPlaylistGroupItemClickedListener
import com.loopnow.fireworklibrary.models.VideoContentStatus
import com.loopnow.fireworklibrary.views.OnItemClickedListener
import com.loopnow.fireworklibrary.views.OnVideoContentStatusListener
import io.flutter.plugin.common.BinaryMessenger
import io.flutter.plugin.common.MethodChannel
import io.flutter.plugin.platform.PlatformView

class FWVideoFeedPlatformView(
    activity: Activity,
    id: Int,
    creationParams: Map<String?, Any?>?,
    binaryMessenger : BinaryMessenger,
    fwSdkModuleChannel: MethodChannel?,
): PlatformView {

    val videoFeed: FWVideoFeed = FWVideoFeed(activity)
    private val methodChannel = MethodChannel(
        binaryMessenger,
        FWChannelName.FireworkVideoFeed.rawValue.replace("(viewId)", "$id")
    )

    private val fwSdkModuleChannel by weakProperty<MethodChannel?>(fwSdkModuleChannel)

    init {
        methodChannel.setMethodCallHandler(FWVideoFeedHandler(this))

        val videoFeedProps: FWVideoFeedPropsModel? = FWGsonUtil.fromObject(creationParams, FWVideoFeedPropsModel::class.java)
        setProps(videoFeedProps)
        addVideoFeedListener()
        addPlaylistGroupFeedListener()
    }

    private fun setProps(props: FWVideoFeedPropsModel?) {
        videoFeed.setProps(props)
    }

    private fun addVideoFeedListener() {
        videoFeed.videoFeedView?.addOnItemClickedListener(object: OnItemClickedListener {
            override fun onItemClicked(index: Int, title: String, id: String, videoDuration: Long) {
                val fwVideoFeedItemDetailsModel = FWVideoFeedItemDetailsModel(
                    index,
                    id,
                    videoDuration.toInt(),
                    videoFeed.videoFeedPropsModel.source,
                    title,
                    videoFeed.videoFeedPropsModel.playlistGroup,
                    videoFeed.videoFeedPropsModel.playlist,
                    videoFeed.videoFeedPropsModel.channel,
                    videoFeed.videoFeedPropsModel.dynamicContentParameters
                )
                FWEventUtils.sendVideoFeedClickEvent(fwSdkModuleChannel, fwVideoFeedItemDetailsModel)
            }

            override fun onItemClicked(index: Int) {
                super.onItemClicked(index)
            }

            override fun onItemClicked(index: Int, feedId: Int): Boolean {
                return super.onItemClicked(index, feedId)
            }
        })
        videoFeed.videoFeedView?.addOnVideoContentStatusListener(object: OnVideoContentStatusListener {
            override fun currentStatus(status: VideoContentStatus, extra: String) {
                when (status) {
                    VideoContentStatus.LoadingContent -> {
                        FWLogUtils.d { "VideoContentStatus.LoadingContent" }
                    }
                    VideoContentStatus.LoadingContentFailed -> {
                        FWLogUtils.e { "VideoContentStatus.LoadingContentFailed" }
                        FWEventUtils.sendVideoFeedLoadFailedEvent(methodChannel, VideoContentStatus.LoadingContentFailed.rawValue, extra)
                    }
                    VideoContentStatus.ContentLoaded -> {
                        FWLogUtils.d { "VideoContentStatus.ContentLoaded" }
                        FWEventUtils.sendVideoFeedLoadSuccessEvent(methodChannel)
                    }
                    else -> {
                        FWLogUtils.d { "VideoContentStatus: $status" }
                    }
                }
            }
        })
    }

    private fun addPlaylistGroupFeedListener() {
        videoFeed.playlistGroupFeedView?.itemClickHandler = object :
            OnPlaylistGroupItemClickedListener {
            override fun onItemClicked(index: Int, title: String, id: String): Boolean {
                val fwVideoFeedItemDetailsModel = FWVideoFeedItemDetailsModel(
                    index,
                    id,
                    0,
                    videoFeed.videoFeedPropsModel.source,
                    title,
                    videoFeed.videoFeedPropsModel.playlistGroup,
                    videoFeed.videoFeedPropsModel.playlist,
                    videoFeed.videoFeedPropsModel.channel,
                    videoFeed.videoFeedPropsModel.dynamicContentParameters
                )
                FWEventUtils.sendVideoFeedClickEvent(fwSdkModuleChannel, fwVideoFeedItemDetailsModel)
                return false
            }
        }

        videoFeed.playlistGroupFeedView?.addOnVideoContentStatusListener(object: OnVideoContentStatusListener {
            override fun currentStatus(status: VideoContentStatus, extra: String) {
                when (status) {
                    VideoContentStatus.LoadingContent -> {
                        FWLogUtils.d { "VideoContentStatus.LoadingContent" }
                    }
                    VideoContentStatus.LoadingContentFailed -> {
                        FWLogUtils.e { "VideoContentStatus.LoadingContentFailed" }
                        FWEventUtils.sendVideoFeedLoadFailedEvent(methodChannel, VideoContentStatus.LoadingContentFailed.rawValue, extra)
                    }
                    VideoContentStatus.ContentLoaded -> {
                        FWLogUtils.d { "VideoContentStatus.ContentLoaded" }
                        FWEventUtils.sendVideoFeedLoadSuccessEvent(methodChannel)
                    }
                    else -> {}
                }
            }
        })
    }

    override fun getView(): View {
        return videoFeed
    }

    override fun dispose() {
    }
}
